@@ -6,9 +6,10 @@ This module contains tests for Role objects.
 import pytest
 
 from mokkari import exceptions, issue
+from mokkari.session import Session
 
 
-def test_role_list(talker):
+def test_role_list(talker: Session) -> None:
     """Test the RoleList."""
     roles = talker.role_list({"name": "editor"})
     role_iter = iter(roles)
@@ -19,7 +20,7 @@ def test_role_list(talker):
     assert roles[1].name == "Consulting Editor"
 
 
-def test_bad_response_data(talker):
+def test_bad_response_data() -> None:
     """Test for a bad role response."""
     with pytest.raises(exceptions.ApiError):
         issue.RoleList({"results": {"name": 1}})
